Reference File Types
====================

The ``source_catalog`` step uses APCORR and ABVEGAOFFSET reference
files.

.. include:: ../references_general/apcorr_reffile.inc

.. include:: ../references_general/abvegaoffset_reffile.inc
